import React from 'react';
import { Globe, Rocket, Target, Layout, Code, ArrowRight, Gauge, Users, Zap, Phone, Bot, MessageCircle } from 'lucide-react';

const AIPhoneAssistant = () => {
  const features = [
    {
      icon: <MessageCircle className="w-6 h-6" />,
      title: 'Natural Conversations',
      description: 'AI-powered voice interactions that feel human and understand context'
    },
    {
      icon: <Zap className="w-6 h-6" />,
      title: 'Smart Call Routing',
      description: 'Intelligent call handling and qualification based on prospect needs'
    },
    {
      icon: <Code className="w-6 h-6" />,
      title: 'Seamless Integration',
      description: 'Works with your existing phone system and CRM for unified communication'
    }
  ];

  const stats = [
    { label: 'Call Response Rate', value: '100%', trend: '24/7' },
    { label: 'Avg. Call Duration', value: '4.2m', trend: 'Optimized' },
    { label: 'Lead Qualification Rate', value: '85%', trend: 'AI-Powered' }
  ];

  return (
    <section id="ai-phone-assistant" className="relative py-16 overflow-hidden">
      {/* Subtle gradient background */}
      <div className="absolute inset-0">
        <div className="absolute inset-0 bg-gradient-to-b from-white via-primary-50/30 to-white" />
      </div>

      <div className="relative max-w-7xl mx-auto px-4">
        <div className="text-center mb-12">
          <div className="inline-flex items-center gap-2 px-4 py-2 rounded-full bg-primary-50 border border-primary-100 mb-4">
            <div className="p-1 bg-gradient-to-r from-primary-500 to-primary-600 rounded-full">
              <Phone className="w-4 h-4 text-white" />
            </div>
            <span className="text-sm font-medium text-primary-700">
              AI PHONE ASSISTANT
            </span>
          </div>
          
          <h2 className="text-4xl lg:text-5xl font-bold text-secondary-900 mb-4" aria-label="AI-Powered Phone Communication System">
            Intelligent Phone
            <span className="block mt-2 text-gradient">Communication Assistant</span>
          </h2>
          
          <p className="text-xl text-secondary-600 max-w-2xl mx-auto" aria-label="24/7 AI phone assistant for business communication">
            Our AI phone assistant handles calls, schedules meetings, and qualifies leads 24/7. Experience natural conversations that convert prospects into customers.
          </p>
        </div>

        <div className="grid lg:grid-cols-5 gap-8 items-start">
          {/* Left Side - Features */}
          <div className="lg:col-span-2 space-y-6">
            {features.map((feature, index) => (
              <div 
                key={index} 
                className="group bg-white rounded-2xl p-6 border border-primary-100/50 shadow-soft hover:shadow-lg transition-all relative overflow-hidden"
              >
                <div className="absolute inset-0 bg-gradient-to-br from-primary-50/0 via-primary-50/30 to-primary-50/0 -translate-x-full group-hover:translate-x-full transition-transform duration-1000" />
                <div className="flex items-start gap-4">
                  <div className="relative">
                    <div className="absolute inset-0 bg-gradient-to-br from-primary-500/20 to-primary-600/20 rounded-xl blur-lg opacity-0 group-hover:opacity-100 transition-opacity" />
                    <div className="relative w-12 h-12 rounded-xl bg-primary-50 flex items-center justify-center group-hover:scale-110 transition-transform">
                      {feature.icon}
                    </div>
                  </div>
                  <div>
                    <h3 className="font-semibold text-secondary-900 mb-2 group-hover:text-gradient transition-colors">{feature.title}</h3>
                    <p className="text-secondary-600">{feature.description}</p>
                  </div>
                </div>
              </div>
            ))}

            <div className="mt-8 flex justify-center">
              <div className="flex flex-col sm:flex-row w-full sm:w-auto gap-4 sm:gap-6">
                <a
                  href="#contact"
                  className="btn-primary group w-full sm:w-auto"
                >
                  Start Your Project
                  <ArrowRight className="ml-2 w-5 h-5 group-hover:translate-x-0.5 transition-transform" />
                </a>
                <a
                  href="/demo"
                  className="btn-secondary group w-full sm:w-auto"
                >
                  Try Demo
                  <ArrowRight className="ml-2 w-5 h-5 group-hover:translate-x-0.5 transition-transform" />
                </a>
              </div>
            </div>
          </div>

          {/* Center - Phone Interface */}
          <div className="lg:col-span-3 relative">
            {/* Main interface */}
            <div className="relative bg-white rounded-3xl border border-primary-100/50 shadow-soft p-8 overflow-hidden">
              {/* Background decoration */}
              <div className="absolute inset-0 bg-gradient-to-br from-primary-50/30 to-transparent" />
              <div className="absolute top-0 right-0 w-64 h-64 bg-gradient-to-br from-primary-500/10 to-primary-600/10 rounded-full blur-3xl -translate-y-1/2 translate-x-1/2" />
              
              <div className="space-y-8">
                {/* Interface header */}
                <div className="flex items-center justify-between">
                  <div className="flex items-center gap-4">
                    <div className="w-16 h-16 rounded-2xl bg-gradient-to-br from-primary-50 to-primary-100 flex items-center justify-center relative group">
                      <div className="absolute inset-0 bg-gradient-to-br from-primary-500/20 to-primary-600/20 rounded-2xl blur-lg opacity-0 group-hover:opacity-100 transition-opacity" />
                      <div className="relative">
                        <Phone className="w-6 h-6 text-primary-600" />
                      </div>
                    </div>
                    <div>
                      <h3 className="text-xl font-semibold text-secondary-900">AI Phone Assistant</h3>
                      <p className="text-sm text-secondary-600">Active Conversations</p>
                    </div>
                  </div>
                  <div className="px-3 py-1 rounded-full bg-green-50 text-green-700 text-sm border border-green-100">
                    Monitor Calls
                  </div>
                </div>

                {/* Call Stats */}
                <div className="space-y-4">
                  {stats.map((stat, index) => (
                    <div 
                      key={index} 
                      className="group bg-white rounded-2xl p-6 border border-primary-100/50 shadow-sm hover:shadow-md transition-all relative overflow-hidden"
                    >
                      {/* Hover effect */}
                      <div className="absolute inset-0 bg-gradient-to-r from-primary-50/0 via-primary-50/30 to-primary-50/0 -translate-x-full group-hover:translate-x-full transition-transform duration-1000" />
                      
                      <div className="flex justify-between items-center">
                        <div>
                          <p className="text-sm text-secondary-600 mb-1">{stat.label}</p>
                          <p className="text-3xl font-bold text-gradient group-hover:scale-105 transition-transform">
                            {stat.value}
                          </p>
                        </div>
                        <span className="px-3 py-1 rounded-full text-sm bg-green-50 text-green-700 border border-green-100">
                          {stat.trend}
                        </span>
                      </div>
                    </div>
                  ))}
                </div>
                
                {/* Active Call Visualization */}
                <div className="relative bg-secondary-50/50 rounded-2xl p-6 border border-secondary-100">
                  <div className="flex items-center gap-4 mb-4">
                    <div className="w-10 h-10 rounded-full bg-green-100 flex items-center justify-center animate-pulse">
                      <Phone className="w-5 h-5 text-green-600" />
                    </div>
                    <div>
                      <div className="text-sm font-medium text-secondary-900">Active Call</div>
                      <div className="text-sm text-secondary-600">Duration: 2:45</div>
                    </div>
                    <div className="ml-auto px-3 py-1 rounded-full bg-green-50 text-green-700 text-sm border border-green-100">
                      In Progress
                    </div>
                  </div>
                  
                  <div className="space-y-3">
                    <div className="flex gap-3">
                      <div className="w-8 h-8 rounded-full bg-primary-100 flex items-center justify-center shrink-0">
                        <Bot className="w-4 h-4 text-primary-600" />
                      </div>
                      <div className="bg-white rounded-2xl p-3 text-sm text-secondary-700 border border-secondary-100 shadow-sm">
                        I understand you're interested in our enterprise plan. Could you tell me more about your specific needs?
                      </div>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>
    </section>
  );
};

export default AIPhoneAssistant;